//====================================================================
//Serial Time-Base:
//  Serial port is IUS51 and Vision51 Transmission interface.
//  Timer1 or Timer2(depend on ius_BaudRateUseTimer setting) is used
//  as the UART baud rates generator.
//  To use Timer1 as baud rates generater:
//    For this purpose Timer1 is used in mode 2 (Auto-Reload).
//    Baud Rate = ius_SYSTEM_CLOCK/(iusSTBn*(256-TH1))
//  To use Timer2 as baud rates generator:
//    For this purpose Timer2 is used in Auto-Reload mode.
//    Baud Rate= ius_SYSTEM_CLOCK/(iusSTBn*(65536-RCAP2))
//    The iusSTBn(n can be 0~9) means "Serial Time-Base" thant need
//    defined at here.
//    Also each iusSTBn need define a corresponding iusSETUP_STBn macro.
//    to setup correct Serial Time-Base.
//    For example, the timer 1 of standard 8051 family counting at the
//    rate of 1/12 of the clock frequency.
//    The baud rates formula for serial port in mode 2 is:
//        Baud Rates= (k*ius_SYSTEM_CLOCK)/(32*12*(256-TH1))
//                  = ius_SYSTEM_CLOCK/((32*12/k)*(256-TH1))--->iusSTBn=(32*12/k)
//        Note K= SMOD+1(SMOD is bit 7 of the PCON register)
//        Here we need define two sets of iusSTBn/iusSETUP_STBn: 
//            #define iusSETUP_STB0		PCON &= 0x7F; //SMOD=0
//            #define iusSTB0			(32*12/1)
//            #define iusSETUP_STB1		PCON |= 0x80; //SMOD=1
//            #define iusSTB1			(32*12/2)
//    Macro "iusINIT_SERIAL" also need define here for serial initiation.
//--------------------------------------------------------------------
	//SILICON LABORATORIES C8051F30X
	sfr iusCKCON   = 0x8e;
	sfr iusP0MDIN  = 0xf1;
	sfr iusP0MDOUT = 0xa4;
	sfr iusOSCXCN  = 0xb1;
		#define XTLVLD		0x80	//External Clock Stable
		#define XOSCMD_OSC1	0x60	//Crystal Oscilator without divide
		#define XFCN_1030	0x07	//means External Oscilator Freq 10~30 MHz
	sfr iusOSCICN  = 0xb2;
	sfr iusOSCICL  = 0xb3;
	sfr iusXBR0    = 0xe1;
	sfr iusXBR1    = 0xe2;
	sfr iusXBR2    = 0xe3;
	sfr iusRSTSRC  = 0xef;		//Reset Source
		#define ResetSource 0x36	//bit5(C0RSEF),bit4(SWRSF),bit2(MCDRSF),bit1(PORSF)
	sfr iusPCA0MD  = 0xd9;
		#define EnWDTimer	0x40	//bit6(WDTE)
	
	#if ius_BaudRateUseTimer==1
	//Serial port use MODE 1, Timer 1 used mode 0 (Auto-Reload)(same as 8052 mode 2)
	//Baud Rates= (ius_SYSTEM_CLOCK)/((2*prescale)*(256-TH1))	--->iusSTBn = 2
		#define iusINIT_SERIAL	SCON=0x50, TMOD = 0x21;	//timer 0 ,16 bit(fix)
	//	The STB0 cover BaudRate 921600 ~ 4800
		#define iusSETUP_STB0	iusCKCON=(iusCKCON & 0xe4) | 0x08;	//use ius_SYSTEM_CLOCK/12
		#define iusSTB0			(2UL*12)						//timer 0 use Systemclock
	//	The STB0 cover BaudRate 230400 ~ 1200
		#define iusSETUP_STB1	iusCKCON=(iusCKCON & 0xe4) | 0x0a;	//use ius_SYSTEM_CLOCK/48
		#define iusSTB1			(2UL*48)
	//
	#elif ius_BaudRateUseTimer==2
		>>> Error: //Baud rates can not generated by Timer 2
	#endif

